"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.App = void 0;
const Debug = require("debug");
const server_1 = require("./server");
const fs_1 = require("fs");
const path = require("path");
const debug = Debug('kamand-app');
class App {
    init(rootPath, fastifyOptions = {}, socketOptions = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            this.server = new server_1.Server();
            process.on('SIGINT', () => __awaiter(this, void 0, void 0, function* () {
                this.stop();
            }));
            debug(`starting...`);
            yield this.server.run(process.env.SERVER_HOST || '0.0.0.0', parseInt(process.env.SERVER_PORT || '8050'), process.env.WEBSOCKET_HOST || '0.0.0.0', parseInt(process.env.WEBSOCKET_PORT || '8040'), fastifyOptions, socketOptions);
            const repositories = [];
            {
                const searchForRepositories = (normalizedPath) => {
                    fs_1.readdirSync(normalizedPath).forEach((file) => {
                        const stat = fs_1.lstatSync(path.join(normalizedPath, file));
                        if (stat.isDirectory()) {
                            const normalizedPathR = path.join(normalizedPath, file);
                            searchForRepositories(normalizedPathR);
                        }
                        if (stat.isFile() && file.match(/-(repository|report|listener).[jt]s$/)) {
                            const relativePath = path.relative(__dirname, path.join(normalizedPath, file));
                            repositories.push((relativePath.startsWith('.') ? '' : './') + relativePath.substring(0, relativePath.length - 3));
                        }
                    });
                };
                const normalizedPath = path.join(rootPath, 'repositories');
                searchForRepositories(normalizedPath);
            }
            yield Promise.all(repositories.map((file) => __awaiter(this, void 0, void 0, function* () {
                debug(file);
                const repo = yield Promise.resolve().then(() => require(file));
                if (repo.models) {
                    this.server.registerModel(repo.models);
                }
                if (repo.queries) {
                    this.server.registerQueryBuilder(repo.queries);
                }
                if (repo.listener) {
                    this.server.regsiterEventListener(repo.listener);
                }
            })));
            debug('repositories loaded');
        });
    }
    stop() {
        return __awaiter(this, void 0, void 0, function* () {
            debug('stopping');
            try {
                yield this.server.stop();
                process.exit(0);
            }
            catch (err) {
                console.error(err);
                process.exit(1);
            }
        });
    }
    listenNetwork() {
        this.server.listenNetwork();
    }
}
exports.App = App;
//# sourceMappingURL=app.js.map